
/*!
 * \file GAME.c
 * \brief Game Source File
 * \authors Tin
 * \version 1
 * \date 03/03/2021
 *
 * Explanation.
 *
 */

#include <stdio.h>
#include <SDL2/SDL.h>
#include <SDL2/SDL_image.h>
#include <SDL2/SDL_ttf.h>
#include "GAME.h"
#include "prof.h"
#include "personnage.h"
#include "map.h"
#include "DS.h"

void load_teacher_textures(SDL_Renderer * renderer, SDL_Texture ** container_textures_teacher){
	container_textures_teacher[0] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_0.png");
	container_textures_teacher[1] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_1.png");
	container_textures_teacher[2] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_2.png");
    container_textures_teacher[3] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_3.png");
	container_textures_teacher[4] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_4.png");
    container_textures_teacher[5] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_5.png");
	container_textures_teacher[6] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_6.png");
    container_textures_teacher[7] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_left_7.png");
	
	container_textures_teacher[8] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_0.png");
    container_textures_teacher[9] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_1.png");
	container_textures_teacher[10] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_2.png");
    container_textures_teacher[11] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_3.png");
	container_textures_teacher[12] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_4.png");
    container_textures_teacher[13] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_5.png");
	container_textures_teacher[14] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_6.png");
    container_textures_teacher[15] = IMG_LoadTexture(renderer,"../ressource/animation_prof/prof_right_7.png");
    

    
	
	
}

void load_hero_textures(SDL_Renderer * renderer, SDL_Texture ** container_textures_hero){
	
	container_textures_hero[0] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_up_0.png");
    container_textures_hero[1] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_up_1.png");
    container_textures_hero[2] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_up_2.png");
    container_textures_hero[3] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_up_3.png");
    container_textures_hero[4] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_down_0.png");
    container_textures_hero[5] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_down_1.png");
    container_textures_hero[6] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_down_2.png");
    container_textures_hero[7] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_down_3.png");
    container_textures_hero[8] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_left_0.png");
    container_textures_hero[9] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_left_1.png");
    container_textures_hero[10] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_left_2.png");
    container_textures_hero[11] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_left_3.png");
    container_textures_hero[12] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_right_0.png");
    container_textures_hero[13] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_right_1.png");
    container_textures_hero[14] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_right_2.png");
    container_textures_hero[15] = IMG_LoadTexture(renderer,"../ressource/animation_hero/hero_right_3.png");
	
	
}

void load_timer_textures(SDL_Renderer * renderer, SDL_Texture ** container_timer, int number_second_max){
	int i;
	
	char timerString[3];
	
    SDL_Color white = {255, 255, 255};  //  text's color

    
	
    TTF_Font* Sans = TTF_OpenFont("../ressource/OpenSans-Semibold.ttf", 8); //font style and sets a size
	
    TTF_SetFontStyle(Sans, 2);
    
	
	for(i = number_second_max; i >= 0 ; i --){

        sprintf(timerString,"%d",i);

		SDL_Surface* timer_surface = TTF_RenderText_Solid(Sans, timerString , white);
		container_timer[i] = SDL_CreateTextureFromSurface(renderer, timer_surface);
		SDL_FreeSurface(timer_surface);
		 
	}
	
	TTF_CloseFont(Sans);
	
}
void free_Textures(SDL_Texture ** container, int number_of_second)
{
	
    int i;
	for(i = number_of_second; i>=0 ; i--){
		SDL_DestroyTexture(container[i]);
		
	}
    free(container);
	
}



void copy_hero(Personnage * hero, SDL_Rect * hero_rect, SDL_Renderer * renderer, SDL_Texture ** container_textures_hero){

    if(hero->animation.direction_personnage==STAY)
                        switch (hero->last_direction) {
                            case 0:
                                SDL_RenderCopy(renderer, container_textures_hero[12], NULL, hero_rect);
                                break;
                            case 1:
                                SDL_RenderCopy(renderer, container_textures_hero[0], NULL, hero_rect);
                                break;
                            case 2:
                                SDL_RenderCopy(renderer, container_textures_hero[4], NULL, hero_rect);
                                break;
                            case 3:
                                SDL_RenderCopy(renderer, container_textures_hero[8], NULL, hero_rect);
                                break;
                            case 4:
                                SDL_RenderCopy(renderer, container_textures_hero[12], NULL, hero_rect);
                                break;
                        }
                    else {
                        switch (hero->animation.direction_personnage) {
                            case UPP:
                                switch (hero->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_hero[0], NULL, hero_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_hero[1], NULL, hero_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_hero[2], NULL, hero_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_hero[3], NULL, hero_rect);
                                        break;
                                }
                                break;
                            case DOWNN:
                                switch (hero->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_hero[4], NULL, hero_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_hero[5], NULL, hero_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_hero[6], NULL, hero_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_hero[7], NULL, hero_rect);
                                        break;

                                }
                                break;
                            case LEFTT:
                                switch (hero->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_hero[8], NULL, hero_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_hero[9], NULL, hero_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_hero[10], NULL, hero_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_hero[11], NULL, hero_rect);
                                        break;

                                }
                                break;
                            case RIGHTT:
                                switch (hero->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_hero[12], NULL, hero_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_hero[13], NULL, hero_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_hero[14], NULL, hero_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_hero[15], NULL, hero_rect);
                                        break;

                                }
                                break;
                        }
                    }
}

void copy_teacher(Prof * teacher, SDL_Rect * teacher_rect, SDL_Renderer * renderer, SDL_Texture ** container_textures_teacher){

                        switch (teacher->animation.direction_teacher) {
                            case UP:
                                switch (teacher->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_teacher[0], NULL, teacher_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_teacher[1], NULL, teacher_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_teacher[2], NULL, teacher_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_teacher[3], NULL, teacher_rect);
                                        break;
									case 4:
                                        SDL_RenderCopy(renderer, container_textures_teacher[4], NULL, teacher_rect);
                                        break;
                                    case 5:
                                        SDL_RenderCopy(renderer, container_textures_teacher[5], NULL, teacher_rect);
                                        break;
                                    case 6:
                                        SDL_RenderCopy(renderer, container_textures_teacher[6], NULL, teacher_rect);
                                        break;
                                    case 7:
                                        SDL_RenderCopy(renderer, container_textures_teacher[7], NULL, teacher_rect);
                                        break;
										
                                }
                                break;
                            case DOWN:
                                switch (teacher->animation.index_image/3) {
									case 0:
                                        SDL_RenderCopy(renderer, container_textures_teacher[8], NULL, teacher_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_teacher[9], NULL, teacher_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_teacher[10], NULL, teacher_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_teacher[11], NULL, teacher_rect);
                                        break;
                                    case 4:
                                        SDL_RenderCopy(renderer, container_textures_teacher[12], NULL, teacher_rect);
                                        break;
                                    case 5:
                                        SDL_RenderCopy(renderer, container_textures_teacher[13], NULL, teacher_rect);
                                        break;
                                    case 6:
                                        SDL_RenderCopy(renderer, container_textures_teacher[14], NULL, teacher_rect);
                                        break;
                                    case 7:
                                        SDL_RenderCopy(renderer, container_textures_teacher[15], NULL, teacher_rect);
                                        break;

                                }
                                break;
                            case LEFT:
                                switch (teacher->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_teacher[0], NULL, teacher_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_teacher[1], NULL, teacher_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_teacher[2], NULL, teacher_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_teacher[3], NULL, teacher_rect);
                                        break;
									case 4:
                                        SDL_RenderCopy(renderer, container_textures_teacher[4], NULL, teacher_rect);
                                        break;
                                    case 5:
                                        SDL_RenderCopy(renderer, container_textures_teacher[5], NULL, teacher_rect);
                                        break;
                                    case 6:
                                        SDL_RenderCopy(renderer, container_textures_teacher[6], NULL, teacher_rect);
                                        break;
                                    case 7:
                                        SDL_RenderCopy(renderer, container_textures_teacher[7], NULL, teacher_rect);
                                        break;

                                }
                                break;
                            case RIGHT:
                                switch (teacher->animation.index_image/3) {
                                    case 0:
                                        SDL_RenderCopy(renderer, container_textures_teacher[8], NULL, teacher_rect);
                                        break;
                                    case 1:
                                        SDL_RenderCopy(renderer, container_textures_teacher[9], NULL, teacher_rect);
                                        break;
                                    case 2:
                                        SDL_RenderCopy(renderer, container_textures_teacher[10], NULL, teacher_rect);
                                        break;
                                    case 3:
                                        SDL_RenderCopy(renderer, container_textures_teacher[11], NULL, teacher_rect);
                                        break;
                                    case 4:
                                        SDL_RenderCopy(renderer, container_textures_teacher[12], NULL, teacher_rect);
                                        break;
                                    case 5:
                                        SDL_RenderCopy(renderer, container_textures_teacher[13], NULL, teacher_rect);
                                        break;
                                    case 6:
                                        SDL_RenderCopy(renderer, container_textures_teacher[14], NULL, teacher_rect);
                                        break;
                                    case 7:
                                        SDL_RenderCopy(renderer, container_textures_teacher[15], NULL, teacher_rect);
                                        break;

                                }
                                break;
                        }
                    
}

/*!
 * \fn SDL_Texture * query_heart(SDL_Rect * heart_rect, SDL_Renderer * renderer, SDL_Window * window, char * path)
 * \brief This function query a picture into a texture for heart's life
 *
 * \param [in] path the path of 1, 2 or 3 heart
 * \param [in] heart_rect the pointer to the structure rect of heart
 * \param [in] renderer the renderer pointer
 * \param [in] window the window pointer
 */
SDL_Texture * query_heart(SDL_Rect * heart_rect, SDL_Renderer * renderer, SDL_Window * window, char * path){
    SDL_Texture * texture_heart;

    // load the image data into the graphics hardware's memory
    texture_heart = IMG_LoadTexture(renderer, path);

    if (!texture_heart)
    {
        printf("Cannot create texture for heart: %s\n", SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return NULL;
    }

    // get and scale the dimensions of texture
    SDL_QueryTexture(texture_heart, NULL, NULL, &heart_rect->w, &heart_rect->h);
    heart_rect->w =  75;
    heart_rect->h =  50;
    heart_rect->x =  620;
    heart_rect->y =  -5;
    return texture_heart;
}



/*!
 * \fn SDL_Texture * query_exam(DS * exam, SDL_Rect * exam_rect, SDL_Renderer * renderer, SDL_Window * window)
 * \brief This function query a picture into a texture for exam
 *
 * \param [in] exam the exam pointer
 * \param [in] exam_rect the pointer to the structure rect of exam
 * \param [in] renderer the renderer pointer
 * \param [in] window the window pointer
 */
 
SDL_Texture * query_exam(DS * exam, SDL_Rect * exam_rect, SDL_Renderer * renderer, SDL_Window * window){

    SDL_Texture * texture_exam;

    // load the image data into the graphics hardware's memory
    texture_exam = IMG_LoadTexture(renderer, exam->image_DS);

    if (!texture_exam)
    {
        printf("error creating texture for exam: %s\n", SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return NULL;
    }

    SDL_QueryTexture(texture_exam, NULL, NULL, &exam_rect->w, &exam_rect->h);
    exam_rect->w /= 30;
    exam_rect->h /= 35;
    exam_rect->x=exam->x_DS;
    exam_rect->y=exam->y_DS;

    return texture_exam;
}


/*!
 * \fn SDL_Texture * query_map(MAP * map_game, SDL_Renderer * renderer, SDL_Window * window)
 * \brief This function query a picture into a texture for map
 *
 * \param [in] map_game the map of game's pointer
 * \param [in] renderer the renderer pointer
 * \param [in] window the window pointer
 */
SDL_Texture * query_map(MAP * map_game, SDL_Renderer * renderer, SDL_Window * window){
    init_map(map_game,"../ressource/colored.bmp","../ressource/map_play.bmp");
    map_game->functional = maptomatrix(map_game);

    //Create a texture for map
    SDL_Texture * texture_map = IMG_LoadTexture(renderer, map_game->visual_path);

    if (!texture_map)
    {
        printf("error creating texture for map: %s\n", SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return NULL;
    }

    return texture_map;
}


/*!
 * \fn SDL_Texture * query_score(SDL_Renderer *renderer, SDL_Rect* score_rect, SDL_Window * window, int* score)
 * \brief This function query a score texture
 *
 * \param [in] score_rect the SDL rect of score
 * \param [in] renderer the renderer pointer
 * \param [in] window the window pointer
 * \param [in] score the score pointer
 */
SDL_Texture * query_score(SDL_Renderer *renderer, SDL_Rect* score_rect, SDL_Window * window, int* score){
	
	char scoreString[10];
	
    SDL_Color white = {255, 255, 255};  //  text's color

    sprintf(scoreString,"%d",*score);
	
    TTF_Font* Sans = TTF_OpenFont("../ressource/OpenSans-Semibold.ttf", 8); //font style and sets a size
	
    TTF_SetFontStyle(Sans, 2);
    SDL_Surface* score_surface = TTF_RenderText_Solid(Sans, scoreString , white);
    SDL_Texture* texture_score = SDL_CreateTextureFromSurface(renderer, score_surface);
    SDL_FreeSurface(score_surface);
	TTF_CloseFont(Sans);
	
    // draw the image to the window
    if (!texture_score)
    {
        printf("error creating texture for score: %s\n", SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return NULL;
    }

    score_rect->x = 330;  //controls the rect's x coordinate
    score_rect->y = 394; // controls the rect's y coordinte
    score_rect->w = 100; // controls the width of the rect
    score_rect->h = 128; // controls the height of the rect
	
	
    return texture_score;
}


/*!
 * \fn int show_image_in_time(SDL_Renderer* renderer, SDL_Window * window, char * path, int time)
 * \brief This function show an image in some duration
 *
 * \param [in] renderer the renderer pointer
 * \param [in] window the window pointer
 * \param [in] path the path of image
 * \param [in] time the duration
 */

int show_image_in_time(SDL_Renderer* renderer, SDL_Window * window, char * path, int time) {
//texture for beginning page
    SDL_Texture *texture;
    texture = IMG_LoadTexture(renderer, path);
    if (!texture) {
        printf("error creating texture for image %s: %s\n",path, SDL_GetError());
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }
    SDL_RenderCopy(renderer, texture, NULL, NULL);
	
    SDL_RenderPresent(renderer);
	
	SDL_DestroyTexture(texture);
	
    SDL_Delay(time);
    
    return 0;
}
/*!
 * \fn int calculer_score(Personnage * hero,  int * time_remaining)
 * \brief This function test and calculate the result of the game
 *
 * \param [in] hero the hero pointer
 * \param [in] time_remaining the time remaining pointer

 */

int calculer_score(Personnage * hero,  int time_remaining, Window * window_play){
    if(hero->result==PLAYING){
		
		if(window_play->level<=3)
			hero->score += 10 * (time_remaining) ;
		else if(window_play->level<=7)
			hero->score += 30 * (time_remaining) ;
		else 
			hero->score += 50 * (time_remaining) ;
			
		return 0;
		
	}
	else if(hero->result==LOSE){
		
		return 1000*hero->DS_took;
	}
	else
	{
		return 1000*10 + 1000*hero->life + hero->score;
	}
}


/*!
 * \fn void test_event_hero(Personnage * hero, SDL_Event * event, int * close)
 * \brief This function test the events of keyboard and change the model of hero and close_request if necessary
 *
 * \param [in] hero the hero pointer
 * \param [in] event the SDL event
 * \param [in] close the close pointer
 */

void test_event_hero(Personnage * hero, SDL_Event * event, int * close){
    while (SDL_PollEvent(event))
    {
        switch (event->type)
        {
            case SDL_QUIT:
                *close = 1;
                hero->result=LOSE;
                break;
            case SDL_KEYDOWN:
                switch (event->key.keysym.scancode) {
                    case SDL_SCANCODE_UP:
                        hero->animation.direction_personnage = 1;
                        break;
                    case SDL_SCANCODE_LEFT:
                        hero->animation.direction_personnage = 3;
                        break;
                    case SDL_SCANCODE_DOWN:
                        hero->animation.direction_personnage = 2;
                        break;
                    case SDL_SCANCODE_RIGHT:
                        hero->animation.direction_personnage = 4;
                        break;
                }

                break;
            case SDL_KEYUP:
                hero->last_direction = hero->animation.direction_personnage;
                hero->animation.direction_personnage = 0;
                hero->animation.index_image=0;
                break;
        }
    }
}


/*!
 * \fn void test_event_hero(Personnage * hero, SDL_Event * event, int * close)
 * \brief This function test the events of keyboard and change the model of hero and close_request if necessary
 *
 * \param [in] hero the hero pointer
 * \param [in] event the SDL event
 * \param [in] close the close pointer
 */

void test_event_hero_inverse(Personnage * hero, SDL_Event * event, int * close){
    while (SDL_PollEvent(event))
    {
        switch (event->type)
        {
            case SDL_QUIT:
                *close = 1;
                hero->result=LOSE;
                break;
            case SDL_KEYDOWN:
                switch (event->key.keysym.scancode) {
                    case SDL_SCANCODE_UP:
                        hero->animation.direction_personnage = 2;
                        break;
                    case SDL_SCANCODE_LEFT:
                        hero->animation.direction_personnage = 4;
                        break;
                    case SDL_SCANCODE_DOWN:
                        hero->animation.direction_personnage = 1;
                        break;
                    case SDL_SCANCODE_RIGHT:
                        hero->animation.direction_personnage = 3;
                        break;
                }

                break;
            case SDL_KEYUP:
                hero->last_direction = hero->animation.direction_personnage;
                hero->animation.direction_personnage = 0;
                hero->animation.index_image=0;
                break;
        }
    }
}

/*!
 * \fn void test_event_hero(Personnage * hero, SDL_Event * event, int * close)
 * \brief This function test the events of keyboard and change the model of hero and close_request if necessary
 *
 * \param [in] hero the hero pointer
 * \param [in] event the SDL event
 * \param [in] close the close pointer
 */

void test_event_hero_combinatoire(Personnage * hero, SDL_Event * event, int * close, int combinatoire){
	
	int combinatoire_gen[24][4] = {
	{1,2,3,4},
	{1,2,4,3},
	{1,3,2,4},
	{1,3,4,2},
	{1,4,2,3},
	{1,4,3,2},
	{2,1,4,3},
	{2,1,3,4},
	{2,3,1,4},
	{2,3,4,1},
	{2,4,1,3},
	{2,4,3,1},
	{3,1,2,4},
	{3,1,4,2},
	{3,2,1,4},
	{3,2,4,1},
	{3,4,2,1},
	{3,4,1,2},
	{4,1,2,3},
	{4,1,3,2},
	{4,2,3,1},
	{4,2,1,3},
	{4,3,2,1},
	{4,3,1,2}
	} ;
	
	
    while (SDL_PollEvent(event))
    {
        switch (event->type)
        {
            case SDL_QUIT:
                *close = 1;
                hero->result=LOSE;
                break;
            case SDL_KEYDOWN:
                switch (event->key.keysym.scancode) {
                    case SDL_SCANCODE_UP:
                        hero->animation.direction_personnage = combinatoire_gen[combinatoire][0];
                        break;
                    case SDL_SCANCODE_LEFT:
                        hero->animation.direction_personnage = combinatoire_gen[combinatoire][1];
                        break;
                    case SDL_SCANCODE_DOWN:
                        hero->animation.direction_personnage = combinatoire_gen[combinatoire][2];
                        break;
                    case SDL_SCANCODE_RIGHT:
                        hero->animation.direction_personnage = combinatoire_gen[combinatoire][3];
                        break;
                }

                break;
            case SDL_KEYUP:
                hero->last_direction = hero->animation.direction_personnage;
                hero->animation.direction_personnage = 0;
                hero->animation.index_image=0;
                break;
        }
    }
}
